@@ -693,7 +693,7 @@ class SerialNumberList(object):
         ret.append( SerialNumberRange(sn0, last=sn1, inc=inc))
         return ret
     
-    def __init__(self, snlist, inc=1, sep=RANGE_SEP_CHAR):
+    def __init__(self, snlist=None, inc=1, sep=RANGE_SEP_CHAR):
         '''Constructor'''
         self._sep = sep
         self._inc = inc
